==> phpMinAdmin-1.7.0.zip: phpMinAdmin-1.7.0/lang/zh.inc.php <==
<?php
$translations = array(
	'Login' => '登录',
	'phpMinAdmin' => 'phpMinAdmin',
	'Logout successful.' => '注销成功.',
	'Invalid credentials.' => '无效凭据.',
	'Server' => '服务器',
	'Username' => '用户名',
	'Password' => '密码',
	'Select database' => '选择数据库',
	'Invalid database.' => '无效数据库.',
	'Create new database' => '创建新数据库',
	'Table has been dropped.' => '已丢弃表.',
	'Table has been altered.' => '已更改表.',
	'Table has been created.' => '已创建表.',
	'Alter table' => '更改表',
	'Create table' => '创建表',
	'Table name' => '表名',
	'engine' => '引擎',
	'collation' => '整理',
	'Column name' => '列名',
	'Type' => '类型',
	'Length' => '长度',
	'NULL' => 'NULL',
	'Auto Increment' => '自动增量',
	'Options' => '选项',
	'Save' => '保存',
	'Drop' => '丢弃',
	'Database has been dropped.' => '数据库已丢弃.',
	'Database has been created.' => '数据库已创建.',
	'Database has been renamed.' => '数据库已重命名.',
	'Database has been altered.' => '数据库已更改.',
	'Alter database' => '更改数据库',
	'Create database' => '创建数据库',
	'SQL command' => 'SQL 命令',
	'Dump' => '转储',
	'Logout' => '注销',
	'database' => '数据库',
	'Use' => '使用',
	'No tables.' => '没有表.',
	'select' => '选择',
	'Create new table' => '创建新表',
	'Item has been deleted.' => '项目已删除.',
	'Item has been updated.' => '项目已更新.',
	'Item has been inserted.' => '项目已插入.',
	'Edit' => '编辑',
	'Insert' => '插入',
	'Save and insert next' => '保存并插入下一个',
	'Delete' => '删除',
	'Database' => '数据库',
	'Routines' => '例程',
	'Indexes has been altered.' => '索引已更改.',
	'Indexes' => '索引',
	'Alter indexes' => '更改索引',
	'Add next' => '添加下一个',
	'Language' => '语言',
	'Select' => '选择',
	'New item' => '新项目',
	'Search' => '搜索',
	'Sort' => '排序',
	'DESC' => '降序',
	'Limit' => '限定',
	'No rows.' => '没有行.',
	'Action' => '动作',
	'edit' => '编辑',
	'Page' => '页面',
	'Query executed OK, %d row(s) affected.' => '执行查询OK, %d 行受影响',
	'Error in query' => '查询出错',
	'Execute' => '执行',
	'Table' => '表',
	'Foreign keys' => '外键',
	'Triggers' => '触发器',
	'View' => '视图',
	'Unable to select the table' => '不能选择该表',
	'Invalid CSRF token. Send the form again.' => '无效 CSRF 令牌. 重新发送表单.',
	'Comment' => '注释',
	'Default values has been set.' => '默认值已设置.',
	'Default values' => '默认值',
	'BOOL' => 'BOOL',
	'Show column comments' => '显示列注释',
	'%d byte(s)' => '%d 字节',
	'No commands to execute.' => '没有命令执行.',
	'Unable to upload a file.' => '不能上传文件.',
	'File upload' => '文件上传',
	'File uploads are disabled.' => '文件上传被禁用.',
	'Routine has been called, %d row(s) affected.' => '例程被调用, %d 行被影响',
	'Call' => '调用',
	'No MySQL extension' => '没有MySQL扩展',
	'None of supported PHP extensions (%s) are available.' => '没有支持的 PHP 扩展可用 (%s).',
	'Sessions must be enabled.' => '会话必须被启用.',
	'Session expired, please login again.' => '会话已过期, 请重新登录.',
	'Text length' => '文本长度',
	'Syntax highlighting' => '语法高亮',
	'Foreign key has been dropped.' => '外键已删除.',
	'Foreign key has been altered.' => '外键已更改.',
	'Foreign key has been created.' => '外键已创建.',
	'Foreign key' => '外键',
	'Target table' => '目标表',
	'Change' => '更改',
	'Source' => '源',
	'Target' => '目标',
	'Add column' => '增加列',
	'Alter' => '更改',
	'Add foreign key' => '添加外键',
	'ON DELETE' => 'ON DELETE',
	'ON UPDATE' => 'ON UPDATE',
	'Index Type' => '索引类型',
	'Column (length)' => '列 (长度)',
	'View has been dropped.' => '视图已丢弃.',
	'View has been altered.' => '视图已更改.',
	'View has been created.' => '视图已创建.',
	'Alter view' => '更改视图',
	'Create view' => '创建视图',
	'Name' => '名称',
	'Process list' => '进程列表',
	'%d process(es) has been killed.' => '%d 个进程被终止',
	'Kill' => '终止',
	'IN-OUT' => 'IN-OUT',
	'Parameter name' => '参数名',
	'Database schema' => '数据库附表',
	'Create procedure' => '创建过程',
	'Create function' => '创建函数',
	'Routine has been dropped.' => '例程已丢弃.',
	'Routine has been altered.' => '例程已更改.',
	'Routine has been created.' => '例程已创建.',
	'Alter function' => '更改函数',
	'Alter procedure' => '更改过程',
	'Return type' => '返回类型',
	'Add trigger' => '创建触发器',
	'Trigger has been dropped.' => '触发器已丢弃.',
	'Trigger has been altered.' => '触发器已更改.',
	'Trigger has been created.' => '触发器已创建.',
	'Alter trigger' => '更改触发器',
	'Create trigger' => '创建触发器',
	'Time' => '时间',
	'Event' => '事件',
	'MySQL version: %s through PHP extension %s' => 'MySQL 版本: %s 通过 PHP 扩展 %s',
	'%d row(s)' => '%d 行',
	'around %d row(s)' => '附近的 %d 行',
	'ON UPDATE CURRENT_TIMESTAMP' => 'ON UPDATE CURRENT_TIMESTAMP',
	'Remove' => '移除',
	'Are you sure?' => '你确定?',
	'Privileges' => '特权',
	'Create user' => '创建用户',
	'User has been dropped.' => '用户已丢弃.',
	'User has been altered.' => '用户已更改.',
	'User has been created.' => '用户已创建.',
	'Hashed' => 'Hashed',
	'Column' => '列',
	'Routine' => '例程',
	'Grant' => '授权',
	'Revoke' => '废除',
	'Error during deleting' => '删除期间出错',
	'%d item(s) have been deleted.' => '%d 个项目被删除',
	'all' => '全部',
	'Delete selected' => '删除选中',
	'Logged as: %s' => '登录为: %s',
	'Too big POST data. Reduce the data or increase the "post_max_size" configuration directive.' => '太大的 POST 数据. 减少数据或者增加 "post_max_size" 配置指令.',
	'Move up' => '上移',
	'Move down' => '下移',
	'Export' => '导出',
	'skip' => '跳过',
	'Tables' => '表',
	'Structure' => '结构',
	'Data' => '数据',
	'Output' => '输出',
	'open' => '打开',
	'save' => '保存',
	'Format' => '格式',
	'SQL' => 'SQL',
	'CSV' => 'CVS',
	'Functions' => '函数',
	'Aggregation' => '集合',
	'Truncate result' => '截断结果',
	'Export selected' => '导出选中',
	'Export result' => '导出结果',
);

==> phpMinAdmin-1.9.1.zip: phpMinAdmin-1.9.1/lang/zh.inc.php <==
<?php
$translations = array(
	'Login' => '登录',
	'phpMinAdmin' => 'phpMinAdmin',
	'Logout successful.' => '注销成功.',
	'Invalid credentials.' => '无效凭据.',
	'Server' => '服务器',
	'Username' => '用户名',
	'Password' => '密码',
	'Select database' => '选择数据库',
	'Invalid database.' => '无效数据库.',
	'Create new database' => '创建新数据库',
	'Table has been dropped.' => '已丢弃表.',
	'Table has been altered.' => '已更改表.',
	'Table has been created.' => '已创建表.',
	'Alter table' => '更改表',
	'Create table' => '创建表',
	'Table name' => '表名',
	'engine' => '引擎',
	'collation' => '校对',
	'Column name' => '列名',
	'Type' => '类型',
	'Length' => '长度',
	'NULL' => 'NULL',
	'Auto Increment' => '自动增量',
	'Options' => '选项',
	'Save' => '保存',
	'Drop' => '丢弃',
	'Database has been dropped.' => '已丢弃数据库.',
	'Database has been created.' => '已创建数据库.',
	'Database has been renamed.' => '已重命名数据库.',
	'Database has been altered.' => '已更改数据库.',
	'Alter database' => '更改数据库',
	'Create database' => '创建数据库',
	'SQL command' => 'SQL命令',
	'Dump' => '转储',
	'Logout' => '注销',
	'database' => '数据库',
	'Use' => '使用',
	'No tables.' => '没有表.',
	'select' => '选择',
	'Create new table' => '创建新表',
	'Item has been deleted.' => '已删除项目.',
	'Item has been updated.' => '已更新项目.',
	'Item has been inserted.' => '已插入项目.',
	'Edit' => '编辑',
	'Insert' => '插入',
	'Save and insert next' => '保存并插入下一个',
	'Delete' => '删除',
	'Database' => '数据库',
	'Routines' => '子程序',
	'Indexes has been altered.' => '已更改索引.',
	'Indexes' => '索引',
	'Alter indexes' => '更改索引',
	'Add next' => '添加下一个',
	'Language' => '语言',
	'Select' => '选择',
	'New item' => '新项目',
	'Search' => '搜索',
	'Sort' => '排序',
	'DESC' => '降序',
	'Limit' => '限定',
	'No rows.' => '没有行.',
	'Action' => '动作',
	'edit' => '编辑',
	'Page' => '页面',
	'Query executed OK, %d row(s) affected.' => '执行查询OK, %d 行受影响',
	'Error in query' => '查询出错',
	'Execute' => '执行',
	'Table' => '表',
	'Foreign keys' => '外键',
	'Triggers' => '触发器',
	'View' => '视图',
	'Unable to select the table' => '不能选择该表',
	'Invalid CSRF token. Send the form again.' => '无效 CSRF 令牌. 重新发送表单.',
	'Comment' => '注释',
	'Default values has been set.' => '默认值已设置.',
	'Default values' => '默认值',
	'BOOL' => 'BOOL',
	'Show column comments' => '显示列注释',
	'%d byte(s)' => '%d 字节',
	'No commands to execute.' => '没有命令执行.',
	'Unable to upload a file.' => '不能上传文件.',
	'File upload' => '文件上传',
	'File uploads are disabled.' => '文件上传被禁用.',
	'Routine has been called, %d row(s) affected.' => '子程序被调用, %d 行被影响',
	'Call' => '调用',
	'No MySQL extension' => '没有MySQL扩展',
	'None of supported PHP extensions (%s) are available.' => '没有支持的 PHP 扩展可用 (%s).',
	'Sessions must be enabled.' => '会话必须被启用.',
	'Session expired, please login again.' => '会话已过期, 请重新登录.',
	'Text length' => '文本长度',
	'Syntax highlighting' => '语法高亮',
	'Foreign key has been dropped.' => '已删除外键.',
	'Foreign key has been altered.' => '已更改外键.',
	'Foreign key has been created.' => '已创建外键.',
	'Foreign key' => '外键',
	'Target table' => '目标表',
	'Change' => '更改',
	'Source' => '源',
	'Target' => '目标',
	'Add column' => '增加列',
	'Alter' => '更改',
	'Add foreign key' => '添加外键',
	'ON DELETE' => 'ON DELETE',
	'ON UPDATE' => 'ON UPDATE',
	'Index Type' => '索引类型',
	'Column (length)' => '列 (长度)',
	'View has been dropped.' => '已丢弃视图.',
	'View has been altered.' => '已更改视图.',
	'View has been created.' => '已创建视图.',
	'Alter view' => '更改视图',
	'Create view' => '创建视图',
	'Name' => '名称',
	'Process list' => '进程列表',
	'%d process(es) has been killed.' => '%d 个进程被终止',
	'Kill' => '终止',
	'IN-OUT' => 'IN-OUT',
	'Parameter name' => '参数名',
	'Database schema' => '数据库概要',
	'Create procedure' => '创建过程',
	'Create function' => '创建函数',
	'Routine has been dropped.' => '已丢弃子程序.',
	'Routine has been altered.' => '已更改子程序.',
	'Routine has been created.' => '已创建子程序.',
	'Alter function' => '更改函数',
	'Alter procedure' => '更改过程',
	'Return type' => '返回类型',
	'Add trigger' => '创建触发器',
	'Trigger has been dropped.' => '已丢弃触发器.',
	'Trigger has been altered.' => '已更改触发器.',
	'Trigger has been created.' => '已创建触发器.',
	'Alter trigger' => '更改触发器',
	'Create trigger' => '创建触发器',
	'Time' => '时间',
	'Event' => '事件',
	'MySQL version: %s through PHP extension %s' => 'MySQL 版本: %s 通过 PHP 扩展 %s',
	'%d row(s)' => '%d 行',
	'ON UPDATE CURRENT_TIMESTAMP' => 'ON UPDATE CURRENT_TIMESTAMP',
	'Remove' => '移除',
	'Are you sure?' => '你确定吗?',
	'Privileges' => '权限',
	'Create user' => '创建用户',
	'User has been dropped.' => '已丢弃用户.',
	'User has been altered.' => '已更改用户.',
	'User has been created.' => '已创建用户.',
	'Hashed' => 'Hashed',
	'Column' => '列',
	'Routine' => '子程序',
	'Grant' => '授权',
	'Revoke' => '废除',
	'Logged as: %s' => '登录为: %s',
	'Too big POST data. Reduce the data or increase the "post_max_size" configuration directive.' => '太大的 POST 数据. 减少数据或者增加 "post_max_size" 配置指令.',
	'Move up' => '上移',
	'Move down' => '下移',
	'Export' => '导出',
	'skip' => '跳过',
	'Tables' => '表',
	'Structure' => '结构',
	'Data' => '数据',
	'Output' => '输出',
	'open' => '打开',
	'save' => '保存',
	'Format' => '格式',
	'SQL' => 'SQL',
	'CSV' => 'CVS',
	'Functions' => '函数',
	'Aggregation' => '集合',
	'Event has been dropped.' => '已丢弃事件.',
	'Event has been altered.' => '已更改事件.',
	'Event has been created.' => '已创建事件.',
	'Alter event' => '更改事件',
	'Create event' => '创建事件',
	'Start' => '开始',
	'End' => '结束',
	'Every' => '每',
	'Status' => '状态',
	'On completion preserve' => '完成后保存',
	'Events' => '事件',
	'Schedule' => '调度',
	'At given time' => '在指定时间',
	'Tables have been truncated.' => '已清空表.',
	'Tables have been moved.' => '已转移表.',
	'Tables and views' => '表和视图',
	'Engine' => '引擎',
	'Collation' => '校对',
	'Data Length' => '数据长度',
	'Index Length' => '索引长度',
	'Data Free' => '数据空闲',
	'Rows' => '行数',
	',' => ',',
	'Analyze' => '分析',
	'Optimize' => '优化',
	'Check' => '检查',
	'Repair' => '修复',
	'Truncate' => '清空',
	'Move to other database' => '转移到其它数据库',
	'Move' => '转移',
	'Save and continue edit' => '保存并继续编辑',
	'original' => '原始',
	'%d item(s) have been affected.' => '%d 个项目受到影响.',
	'whole result' => '全部结果',
	'clone' => '克隆',
	'Tables have been dropped.' => '已丢弃表.',
	'Clone' => '克隆',
);
